@@ -305,8 +305,8 @@ class PyXploraApi:
             raise Exception('Xplora API call finally failed with response: ')
 
 ##### Watch Location Info #####
-    def getWatchLastLocation(self) -> dict:
-        self.loadWatchLocation(False)
+    def getWatchLastLocation(self, withAsk: bool = False) -> dict:
+        self.loadWatchLocation(withAsk)
         return self.watch_last_location
     def getWatchLocate(self) -> dict:
         self.loadWatchLocation()
@@ -335,6 +335,7 @@ class PyXploraApi:
                     for safeZone in safeZones_raw['safeZones']:
                         self.safe_zones.append({
                             #safeZone,
+                            'vendorId': safeZone['vendorId'],
                             'groupName': safeZone['groupName'],
                             'name': safeZone['name'],
                             'lat': safeZone['lat'],
